@@ -16,8 +16,8 @@ if __name__ == '__main__':
         raise SystemExit
     if ARGS.conditionchecker is None:
         validate_inputs(ARGS.path, "repository")
-        ARGS.reportpath = ARGS.path if ARGS.reportpath is None else ARGS.reportpath  # pragma: no mutate
-        validate_inputs(ARGS.reportpath, "report folder")  # pragma: no mutate
+        ARGS.reportpath = ARGS.path if ARGS.reportpath is None else ARGS.reportpath
+        validate_inputs(ARGS.reportpath, "report folder")
         get_report(extractor(ARGS.path, ARGS.annot, ARGS.delta, ARGS.funcstartwith, ARGS.reportpath, ARGS.ignorefiles)
                    , ARGS.reportpath)
     else:
