@@ -1,7 +1,8 @@
 """Koninklijke Philips N.V., 2019 - 2020. All rights reserved."""
 
 import os
-
+import datetime
+import time
 import pandas as pd
 from pandas import DataFrame
 
@@ -12,19 +13,19 @@ def check_condition(condition, file_path_dataframe, splitter=None):
         @parameters
         condition: pattern key word (Ex: @staticmethod, @Test, etc.)
         file_path: Input xlsx file used for searching pattern"""
-    if str(type(file_path_dataframe)) == "<class 'pandas.core.frame.DataFrame'>":
+    if str(type(file_path_dataframe)) == "<class 'pandas.core.frame.DataFrame'>":  # pragma: no mutate
         data = file_path_dataframe
     else:
         extension = os.path.splitext(file_path_dataframe)
-        if extension[1].upper() != ".XLSX":
-            return "Enter Valid Excel File"
+        if extension[1].upper() != ".XLSX":  # pragma: no mutate
+            return "Enter Valid Excel File"  # pragma: no mutate
         data = pd.read_excel(file_path_dataframe)
     test_assert = condition
     if ['Uniq ID'] not in data.columns.ravel():
-        return "Couldn't find Uniq ID column"
+        return "Couldn't find Uniq ID column"  # pragma: no mutate
     data = pd.DataFrame(data, columns=['Uniq ID', 'Code'])
     specifier_column = []
-    spe_data = ""
+    spe_data = ""  # pragma: no mutate
     for i in range(len(data)):
         for line in str(data.iat[i, 1]).splitlines():
             if test_assert.upper() in line.strip().upper():
@@ -62,16 +63,18 @@ def get_pivot_table_result(data, test_assert, splitter, file_path):
         splitter: key to split statement in pivot table
         file_path: Input xlsx file used for searching pattern"""
     specifier_column = clean_data(splitter, data)
-    data_frame = DataFrame(specifier_column, columns=['Count'])
+    data_frame = DataFrame(specifier_column, columns=['Count'])  # pragma: no mutate
     data_table = data_frame.Count.value_counts()
     data_table = data_table.to_frame()
     data_table = data_table.reset_index()
     data_table = data_table.rename({'index': 'Different %s patterns ' % test_assert}, axis='columns')
     if str(type(file_path)) != "<class 'pandas.core.frame.DataFrame'>":  # pragma: no mutate
-        writer = pd.ExcelWriter(os.path.join(os.path.dirname(file_path), 'Pattern_Result_%s.xlsx')
-                                % test_assert.strip("@"), engine='xlsxwriter')
+        file_name = (os.path.join(os.path.dirname(file_path), "Pattern_Result_%s_" +  # pragma: no mutate
+                                  str(datetime.datetime.fromtimestamp(time.time()).strftime(  # pragma: no mutate
+                                      '%H-%M-%S_%d_%m_%Y'))) % test_assert.strip("@"))  # pragma: no mutate
+        writer = pd.ExcelWriter(file_name + ".xlsx", engine='xlsxwriter')  # pragma: no mutate
         data.to_excel(writer, sheet_name='Data')  # pragma: no mutate
-        html_file_path = os.path.join(os.path.dirname(file_path), 'Pivot_table_%s.html') % test_assert.strip("@")
+        html_file_path = file_name + "_Pivot_Table.html"
         data_table.to_excel(writer, sheet_name='Pivot Table')  # pragma: no mutate
         data_table.to_html(html_file_path)
         writer.save()
