@@ -23,15 +23,9 @@ def get_file_names(dir_path):
         dir_path: Path to the repository
         @return
         This function returns all the files in the given directory"""
-    listoffile = os.listdir(dir_path)
-    allfiles = list()
-    for entry in listoffile:
-        fullpath = os.path.join(dir_path, entry)
-        if os.path.isdir(fullpath):
-            allfiles = allfiles + get_file_names(fullpath)
-        else:
-            allfiles.append(fullpath)
-    return allfiles
+    path_list = [os.path.join(dirpath, filename) for dirpath, _, filenames in
+                 os.walk(dir_path) for filename in filenames]
+    return path_list
 
 
 def filter_reg_files(allfiles, reg_pattern):
@@ -48,7 +42,7 @@ def filter_reg_files(allfiles, reg_pattern):
     else:
         reg_pattern = reg_pattern.split(",")
         for i in range(len(reg_pattern).__trunc__()):
-            cmd = "{} " + cmd
+            cmd = "{} " + cmd  # pragma: no mutate
             regex.append(fnmatch.translate(reg_pattern[i]))
         cmd = "(" + cmd[:-1].replace(" ", "|") + ")"  # pragma: no mutate
         re_obj = re.compile(cmd.format(*regex))
@@ -85,7 +79,7 @@ def get_function_names(file_names):
     find = "function" if file_ext.upper() == "CPP" or file_ext.upper() == "C" \
         else ["member", "function", "class"] if file_ext.upper() == "PY" else "method"  # pragma: no mutate
     proc = run_ctags_cmd(file_ext, file_names, find)
-    process = str(proc.stdout.read(), 'utf-8')
+    process = str(proc.stdout.read(), 'utf-8')  # pragma: no mutate
     return process_function_names(process, find)
 
 
@@ -98,8 +92,11 @@ def process_function_names(func_data, find):
         This function returns list of function names and line numbers"""
     if func_data is not None:
         process_list = re.findall(r'\w+', func_data)
-        val = [index for index, _ in enumerate(process_list) if
-               process_list[index - 1] in find and process_list[index].isdigit()]
+        if find == ["member", "function", "class"]:  # pragma: no mutate
+            val = [index for index, _ in enumerate(process_list) if
+                   process_list[index - 1] in find and process_list[index].isdigit()]
+        else:
+            val = process_ctags_output(find, process_list)
         function_list = get_sorted_func_list(process_list, val)
         line_numbers = get_func_line_num_list(process_list, val)
         line_numbers.sort()
@@ -109,6 +106,17 @@ def process_function_names(func_data, find):
     return function_list, line_numbers
 
 
+def process_ctags_output(find, process_list):
+    """ This function cleans the ctags output to get function/method names and line numbers
+        @parameters
+        process_list: Ctags output in list format
+        find: keyword of method type(member/function/class/method)
+        @return
+        This function returns list of function names and line numbers"""
+    return [index for index, _ in enumerate(process_list) if
+            process_list[index - 1] == find and process_list[index].isdigit()]
+
+
 def get_sorted_func_list(process_list, val):
     """ This function sorts function names with respective to line numbers
         @parameters
@@ -180,12 +188,16 @@ def get_annot_methods(filename, line_num, annot):
         This function returns function/method definitions that has the given annotation"""
     file_content = get_file_content(filename)
     iterator = int(line_num) - 2  # Iterating through lines to check for annotations
-    for _ in range(int(line_num) - 2):
-        data = str(file_content[iterator]).strip()
-        iterator = iterator - 1
-        ret_val = process_annot_method_body(annot, data, filename, line_num)
-        if ret_val != "continue":
-            return ret_val
+    try:
+        for _ in range(int(line_num) - 2):  # pragma: no mutate
+            data = str(file_content[iterator]).strip()
+            iterator = iterator - 1
+            ret_val = process_annot_method_body(annot, data, filename, line_num)
+            if ret_val != "continue":  # pragma: no mutate
+                return ret_val
+    except IndexError as exc:
+        LOG.info("error while processing file_line: %s", filename + "_" + line_num)  # pragma: no mutate
+        LOG.info(exc)  # pragma: no mutate
 
 
 def process_annotation(annot):
@@ -214,7 +226,10 @@ def process_annot_method_body(annot, data, filename, line_num):
     annot_start, annot_end = process_annotation(annot)
     if annot.strip(annot_start).strip(annot_end).upper() in data.strip(annot_start) \
             .strip(annot_end).upper().split(",") and data.strip().startswith(annot_start):
-        ret_val = data + os.linesep + get_func_body(filename, line_num)
+        body = get_func_body(filename, line_num)
+        if body is None:
+            body = ""  # pragma: no mutate
+        ret_val = data + os.linesep + str(body)
     elif data[:1] != "@" and str(data).strip() == "}" or str(data).strip() == "{":  # pragma: no mutate
         ret_val = None  # pragma: no mutate
     return ret_val
@@ -230,8 +245,8 @@ def check_py_annot(file_name, annot):
     line_data = list(
         [line.rstrip() for line in open(file_name, encoding='utf-8', errors='ignore')])  # pragma: no mutate
     val = 1  # pragma: no mutate
-    if annot.upper() == "TEST_":  # Making use of annotation search function for function start with feature too
-        annot = "def test_"  # pragma: no mutate
+    if annot[0] != "@":  # Making use of annotation search function for function start with feature too
+        annot = "def " + annot.lower()  # pragma: no mutate
         val = -1  # pragma: no mutate
     return get_py_annot_method_names(line_data, annot, val)
 
@@ -247,13 +262,13 @@ def get_py_annot_method_names(line_data, annot, val):
     data = []
     for i, _ in enumerate(line_data):
         if annot in line_data[i]:
-            if str(line_data[i]).strip().split(" ")[0] == "def":
-                func_name = line_data[i + 1 + val].strip().split(" ")[1].split("(")[0]
+            if str(line_data[i]).strip().split(" ")[0] == "def":  # pragma: no mutate
+                func_name = line_data[i + 1 + val].strip().split(" ")[1].split("(")[0]  # pragma: no mutate
                 data.append(func_name)
             else:
                 for j in range(i, len(line_data)):
-                    if str(line_data[j]).strip().split(" ")[0] == "def":
-                        func_name = line_data[j].strip().split(" ")[1].split("(")[0]
+                    if str(line_data[j]).strip().split(" ")[0] == "def":  # pragma: no mutate
+                        func_name = line_data[j].strip().split(" ")[1].split("(")[0]  # pragma: no mutate
                         data.append(func_name)
                         break
     return data
@@ -266,7 +281,7 @@ def get_func_body(filename, line_num):
         @return
         This function returns function/method definitions of all the given files"""
     line_num = int(line_num)
-    code = ""
+    code = ""  # pragma: no mutate
     cnt_braket = 0
     found_start = False
     return_val = None
@@ -320,8 +335,8 @@ def process_py_methods(file_name, line_numbers, line_data):
     data_func_name = []
     for i, _ in enumerate(line_numbers):
         start = line_numbers[i]
-        stop = len(line_data) if i == len(line_numbers) - 1 else line_numbers[i + 1] - 1  # pragma: no mutate
-        data.append(os.linesep.join(line_data[start - 1:stop]))
+        stop = len(line_data) if i == len(line_numbers) - 1 else line_numbers[i + 1] - 1
+        data.append(os.linesep.join(line_data[start - 1:stop]))  # pragma: no mutate
         data_func_name.append(str(file_name) + "_" + str(line_data[start - 1].strip().split(" ")[1].split("(")[0]))
         if data[len(data) - 1].startswith("class") or "lambda" in data[len(data) - 1]:
             data.remove(data[len(data) - 1])
@@ -392,7 +407,7 @@ def filter_files(list_files):
     This function returns the list of required file(.java, .cpp, .c, .cs, .py) paths """
     local_files = []
     for files in list_files:
-        extension = files.split('.')[-1].upper()
+        extension = files.split('.')[-1].upper()  # pragma: no mutate
         if len(extension).__trunc__() > 0:
             if extension in FILE_TYPE:
                 local_files.append(files)
@@ -403,12 +418,17 @@ def get_delta_lines(file_name, annot, delta):
     """ Function to get + and - delta number of lines from the annoted method/function
             @parameters
             filename, annot, delta: Path to the file, required annotation, required lines from method """
-    line_data = list(filter(None, [line.rstrip() for
-                                   line in open(file_name, encoding='utf-8', errors='ignore')]))  # pragma: no mutate
-    data = []
-    for num, line in enumerate(line_data, 1):
-        process_delta_lines_body(annot, line, delta, num, line_data, data, file_name)
+    try:
+        line_data = list(filter(None, [line.rstrip() for
+                                       line in
+                                       open(file_name, encoding='utf-8', errors='ignore')]))  # pragma: no mutate
         data = []
+        for num, line in enumerate(line_data, 1):
+            process_delta_lines_body(annot, line, delta, num, line_data, data, file_name)
+            data = []
+    except IOError as exc:
+        LOG.info("Cannot read file: %s", file_name)  # pragma: no mutate
+        LOG.info(exc)  # pragma: no mutate
 
 
 def process_delta_lines_body(annot, line, delta, num, line_data, data, file_name):
@@ -620,7 +640,7 @@ def initialize_values(delta, annot, path_loc, report_folder):
     if report_folder is None:
         report_folder = path_loc
     if validate_input_paths(report_folder):
-        return "Enter valid report path"
+        return "Enter valid report path"  # pragma: no mutate
     LOG.info("Input report folder path validated successfully")  # pragma: no mutate
     return report_folder, annot
 
